<?php
/**
* This file accesses the database and retrieves data
*  for adminstrative purposes
* @author Nick Korbel <lqqkout13@users.sourceforge.net>
* @author David Poole <David.Poole@fccc.edu>
* @author Richard Cantzler <rmcii@users.sourceforge.net>
* @version 08-04-05
* @package DBEngine
*
* Copyright (C) 2003 - 2005 phpScheduleIt
* License: GPL, see LICENSE
*/
/**
* Base directory of application
*/
@define('BASE_DIR', dirname(__FILE__) . '/../..');

/**
* DBEngine class
*/
include_once(BASE_DIR . '/lib/DBEngine.class.php');

class AdminDB extends DBEngine {
	
	/**
	* Returns array of user data
	* @param Object $pager pager object
	* @param string $table name of table to retrieve
	* @param string $orders order to return values in
	* @param boolean $limit whether this is a limited query or not
	* @return array of user data
	*/
	function get_all_admin_data(&$pager, $table, $orders, $limit = false) {		
		$return = array();

		if ($limit) {
			$lim = $pager->getLimit();
			$offset = $pager->getOffset();
		}
		else {
			$limit = '';
			$offset = '';
		}
		return $this->get_table_data($table, array('*'), $orders, $lim, $offset);
	}
	
	
	/**
	* Returns an array of all reservation data
	* @param Object $pager pager object
	* @param array $orders order than results should be sorted in
	* @return array of all reservation data
	*/
	function get_reservation_data(&$pager, $orders, $pending=null) {
		$return = array();
		
		$order = CmnFns::get_value_order($orders);	
		$vert = CmnFns::get_vert_order();
		
		if ($order == 'start_date' && !isset($_GET['vert'])) {		// Default the date to DESC
			$vert = 'DESC';
		}
		
		// Clean out the duplicated order so that MSSQL is OK
		$order_str = trim(preg_replace("/(res|l).$order(,)? (DESC|ASC)?(,)?/", '', 'res.start_date DESC, res.startTime, res.endTime, l.lname, l.fname'));
		if (strrpos($order_str, ',') == strlen($order_str)-1) {
			$order_str = substr($order_str, 0, strlen($order_str)-1);
		}

		echo $order_str;
		
		// Set up query to get neccessary records ordered by user request first, then logical order
		$query = 'SELECT res.resid, res.start_date, res.end_date,
			res.startTime, res.endTime,
			res.created, res.modified,
			rs.name,
			l.fname, l.lname, l.memberid
			FROM ' . $this->get_table('reservations') . ' as res, ' . $this->get_table('login') . ' as l, ' . $this->get_table('resources') . ' as rs, ' . $this->get_table('reservation_users') . ' as ru
			WHERE ru.memberid=l.memberid
			AND ru.owner = 1
			AND res.resid = ru.resid
			AND res.machid=rs.machid
			AND res.is_blackout <> 1';

        if( $pending ) {
			$query .= ' AND res.is_pending = 1';
		}
			
		$query .= ' ORDER BY ' . $order . ' ' . $vert . ', ' . $order_str;// 'res.start_date DESC, res.startTime, res.endTime, l.lname, l.fname';
		
		$result = $this->db->limitQuery($query, $pager->getOffset(), $pager->getLimit());
		
		$this->check_for_error($result);
		
		if ($result->numRows() <= 0) {
			if ($pending) {
				$this->err_msg = translate('No reservations requiring approval');
			}
			else {
				$this->err_msg = translate('No results');
			}
			
			return false;
		}
				
		while ($rs = $result->fetchRow()) {
			$return[] = $this->cleanRow($rs);
		}
		
		$result->free();
		
		return $return;
	}
	
	/**
	* Returns an array of all resource data
	* @param Object $pager pager object
	* @param array $orders order than results should be sorted in
	* @return array of all resource data
	*/
	function get_all_resource_data(&$pager, $orders) {
		$return = array();
		
		$order = CmnFns::get_value_order($orders);	
		$vert = CmnFns::get_vert_order();
		
		// Set up query to get neccessary records ordered by user request first, then logical order
		$query = 'SELECT rs.*, s.scheduleTitle
			FROM ' . $this->get_table('resources') . ' as rs, ' . $this->get_table('schedules') . ' as s 
			WHERE rs.scheduleid=s.scheduleid
			ORDER BY ' . $order . ' ' . $vert;
	
		$result = $this->db->limitQuery($query, $pager->getOffset(), $pager->getLimit());
		
		$this->check_for_error($result);
		
		if ($result->numRows() <= 0) {
			$this->err_msg = translate('No results');
			return false;
		}
				
		while ($rs = $result->fetchRow()) {
			$return[] = $this->cleanRow($rs);
		}
		
		$result->free();
		
		return $return;
	}

	
	/**
	* Returns the number of records from a given table
	*  (for paging purposes)
	* @param string $table table to count
	* @return number of records in the table
	*/
	function get_num_admin_recs($table) {
		$query = 'SELECT COUNT(*) as num FROM ' . $this->get_table($table);
		if ($table == 'reservations')
			$query .= ' WHERE is_blackout <> 1';
		// Get # of records
		$result = $this->db->getRow($query);

		// Check query
		$this->check_for_error($result);
			
		return $result['num'];              // # of records
	}
	
    /**
	* Returns the number of reservations pending approval
	*  (for paging purposes)
	* @param none
	* @return number of reservations pending approval
	*/
	function get_num_pending_res() {
		$query = 'SELECT COUNT(*) as num FROM ' . $this->get_table('reservations') . ' as reservations WHERE is_pending = 1';
		$result = $this->db->getRow($query);

		// Check query
		$this->check_for_error($result);
			
		return $result['num'];              // # of records
	}
	
	/**
	* Returns an array of data about a schedule
	* @param int $scheduleid schedule id
	* @return array of data associated with that schedule
	*/
	function get_schedule_data($scheduleid) {
		
		$result = $this->db->getRow('SELECT * FROM ' . $this->get_table('schedules') . ' WHERE scheduleid=?', array($scheduleid));
		// Check query
		$this->check_for_error($result);
		
		if (count($result) <= 0) {
			$this->err_msg = translate('No results');
			return false;
		}
		
		return $this->cleanRow($result);
	}
	
	/**
	* Inserts a new schedule into the database
	* @param array $rs array of schedule data
	*/
	function add_schedule($rs) {
		$values = array();
		
		$id = $this->get_new_id();
							
		array_push($values, $id);	// Values to insert
		array_push($values, $rs['scheduleTitle']);
		array_push($values, $rs['dayStart']);
		array_push($values, $rs['dayEnd']);
		array_push($values, $rs['timeSpan']);
		array_push($values, 12);
		array_push($values, $rs['weekDayStart']);
		array_push($values, $rs['viewDays']);
		array_push($values, $rs['isHidden']);
		array_push($values, $rs['showSummary']);
		array_push($values, $rs['adminEmail']);
		array_push($values, $rs['dayOffset']);
		
		$q = $this->db->prepare('INSERT INTO ' . $this->get_table('schedules') . 
			' (scheduleid,scheduleTitle,dayStart,dayEnd,timeSpan,timeFormat,weekDayStart,viewDays,isHidden,showSummary,adminEmail,dayOffset)'
			.' VALUES(?,?,?,?,?,?,?,?,?,?,?,?)');
		$result = $this->db->execute($q, $values);
		$this->check_for_error($result);
		
		return $id;
	}
	
	/**
	* Edits resource data in database
	* @param array $rs array of values to edit
	*/
	function edit_schedule($rs) {
		$values = array();
		
		array_push($values, $rs['scheduleTitle']);
		array_push($values, $rs['dayStart']);
		array_push($values, $rs['dayEnd']);
		array_push($values, $rs['timeSpan']);
		array_push($values, $rs['weekDayStart']);
		array_push($values, $rs['viewDays']);
		array_push($values, $rs['isHidden']);
		array_push($values, $rs['showSummary']);
		array_push($values, $rs['adminEmail']);
		array_push($values, $rs['dayOffset']);
		array_push($values, $rs['scheduleid']);
			
		$sql = 'UPDATE '. $this->get_table('schedules') . ' SET'
				. ' scheduleTitle=?, dayStart=?, dayEnd=?, timeSpan=?,'
				. ' weekDayStart=?, viewDays=?, isHidden=?, showSummary=?, adminEmail=?, dayOffset=?'
				. ' WHERE scheduleid=?';
		
		$q = $this->db->prepare($sql);
		$result = $this->db->execute($q, $values);
		$this->check_for_error($result);
	}
	
	/**
	* Delete a list of schedules and all of their reservations
	* @param array $schedules array of schedules
	*/
	function del_schedule($schedules) {
		// Do not delete default schedule
		$default_schedule = $this->db->getOne('SELECT scheduleid FROM ' . $this->get_table('schedules') . ' WHERE isDefault = 1');
		if (($idx = array_search($default_schedule, $schedules)) !== false) {
			unset($schedules[$idx]);
		}
		
		$scheduleids = $this->make_del_list($schedules);
		
		// Get all the ids of reservations that are associated with these schedules
		$result = $this->db->query('SELECT resid FROM ' . $this->get_table('reservations') . ' WHERE scheduleid IN (' . $scheduleids . ')');
		$this->check_for_error($result);		
		$results = array();
		while ($rs = $result->fetchRow()) {
			$results[] = $rs['resid'];
		}
		
		$resids = $this->make_del_list($results);
		$result->free();
		// Delete out of the reservation_users table
		$result = $this->db->query('DELETE FROM ' . $this->get_table('reservation_users') . ' WHERE resid IN (' . $resids . ')');
		$this->check_for_error($result);
		// Delete out of the reservations table
		$result = $result = $this->db->query('DELETE FROM ' . $this->get_table('reservations') . ' WHERE resid IN (' . $resids . ')');
		$this->check_for_error($result);
				
		// Delete all reservations for these schedules
		//$result = $this->db->query('DELETE r, ru'
		//						. ' FROM ' . $this->get_table('reservations') . ' r LEFT JOIN ' . $this->get_table('reservation_users') . ' ru '
		//						. ' ON r.resid = ru.resid WHERE r.scheduleid IN(' . $scheduleids . ')');
		$this->check_for_error($result);
		// Delete all schedules
		$result = $this->db->query('DELETE FROM ' . $this->get_table('schedules') . ' WHERE scheduleid IN(' . $scheduleids . ')');
		$this->check_for_error($result);
		
		$newid = $this->db->getOne('SELECT scheduleid FROM ' . $this->get_table('schedules') . ' WHERE isDefault = 1');
		
		// Reassign all resources from old schedule to default
		$result = $this->db->query('UPDATE ' . $this->get_table('resources') . ' SET scheduleid = ? WHERE scheduleid IN(' . $scheduleids . ')', array($newid));
		
		$this->check_for_error($result);
	}
	
	/**
	* Sets the default schedule
	* @param string $scheduleid id of default schedule
	*/
	function set_default_schedule($scheduleid) {
		$result = $this->db->query('UPDATE ' . $this->get_table('schedules') . ' SET isDefault = 0');
		$this->check_for_error($result);
		
		$result = $this->db->query('UPDATE ' . $this->get_table('schedules') . ' SET isDefault = 1 WHERE scheduleid = ?', array($scheduleid));
		$this->check_for_error($result);
	}
	
	/**
	* Return the number of records found in a search
	*  for use in paging
	* @param string $lname last name to search for
	* @param object $pager pager object
	* @return number of records found
	*/
	function get_num_search_recs($fname, $lname) {
		$result = $this->db->getRow('SELECT COUNT(*) AS num FROM ' . $this->get_table('login')
				. ' WHERE fname LIKE "' . $fname . '%" AND lname LIKE "' . $lname . '%"');
		
		$this->check_for_error($result);
		return $result['num'];		
	}
	
	/**
	* Search for users matching this first and last name and return the results in an array
	* @param string $fname first name to search for
	* @param string $lname last name to search for
	* @param object $pager pager object
	* @param array $orders order to print results in
	* @return array of user data
	*/
	function search_users($fname, $lname, &$pager, $orders) {
		$return = array();
		
		$order = CmnFns::get_value_order($orders);	
		$vert = CmnFns::get_vert_order();
		
		if ($order == 'date' && !isset($_GET['vert']))		// Default the date to DESC
			$vert = 'DESC';
		
		// Set up query to get neccessary records ordered by user request first, then logical order
		$query = 'SELECT l.*'
				. ' FROM ' . $this->get_table('login') . ' as l'
				. '	WHERE fname LIKE "' . $fname . '%" AND lname LIKE "' . $lname . '%"'
				. ' ORDER BY ' . $order . ' ' . $vert . ', l.lname, l.fname';

		$result = $this->db->limitQuery($query, $pager->getOffset(), $pager->getLimit());
		
		$this->check_for_error($result);
		
		if ($result->numRows() <= 0) {
			$this->err_msg = translate('No results');
			return false;
		}
				
		while ($rs = $result->fetchRow()) {
			$return[] = $this->cleanRow($rs);
		}
		
		$result->free();
		
		return $return;
	}
	
	/**
	* Returns an array of data about a resource
	* @param int $machID resource id
	* @return array of data associated with that resource
	*/
	function get_resource_data($machid) {
		
		$result = $this->db->getRow('SELECT * FROM ' . $this->get_table('resources') . ' WHERE machid=?', array($machid));
		// Check query
		$this->check_for_error($result);
		
		if (count($result) <= 0) {
			$this->err_msg = translate('No results');
			return false;
		}
		
		return $this->cleanRow($result);
	}
	
	/**
	* Deletes a list of users from the database
	* @param array $users list of users to delete
	*/
	function del_users($users) {
		$uids = $this->make_del_list($users);
		// Delete users
		$result = $this->db->query('DELETE FROM ' . $this->get_table('login') . ' WHERE memberid IN (' . $uids . ')');
		$this->check_for_error($result);
		// Delete reservation participation
		$result = $this->db->query('DELETE FROM ' . $this->get_table('reservation_users') . ' WHERE memberid IN (' . $uids . ') AND owner <> 1');
		$this->check_for_error($result);
		// Delete all reservations, reservation_users for these users if they owned the reservation
		$result = $this->db->query('SELECT resid FROM ' . $this->get_table('reservation_users') . ' WHERE memberid IN (' . $uids . ') AND owner = 1');
		$this->check_for_error($result);
		$results = array();
		while ($rs = $result->fetchRow()) {
			$results[] = $rs['resid'];
		}
		$resids = $this->make_del_list($results);
		$result->free();
		$result = $this->db->query('DELETE FROM ' . $this->get_table('reservation_users') . ' WHERE resid IN (' . $resids . ')');
		$this->check_for_error($result);
		//$result = $this->db->query('DELETE r, ru FROM ' . $this->get_table('reservations') . ' r LEFT JOIN ' . $this->get_table('reservation_users') . ' ru ON r.resid = ru.resid  WHERE ru.memberid IN (' . $uids . ') AND ru.owner = 1');
		$result = $result = $this->db->query('DELETE FROM ' . $this->get_table('reservations') . ' WHERE resid IN (' . $resids . ')');
		$this->check_for_error($result);
		// Delete permissions
		$result = $this->db->query('DELETE FROM ' . $this->get_table('permission') . ' WHERE memberid IN (' . $uids . ')');
		$this->check_for_error($result);				
	}
	
	/**
	* Inserts a new resource into the database
	* @param array $rs array of resource data
	*/
	function add_resource($rs) {
		$values = array();
		
		$id = $this->get_new_id();
		
		array_push($values, $id);	// Values to insert
		array_push($values, $rs['scheduleid']);
		array_push($values, $rs['name']);
		array_push($values, $rs['location']);
		array_push($values, $rs['rphone']);
		array_push($values, $rs['notes']);
		array_push($values, 'a');
		array_push($values, $rs['minRes']);
		array_push($values, $rs['maxRes']);
		array_push($values, intval(isset($rs['autoAssign'])));
		array_push($values, intval(isset($rs['approval'])));
		array_push($values, intval(isset($rs['allow_multi'])));
		
		$q = $this->db->prepare('INSERT INTO ' . $this->get_table('resources') . ' VALUES(?,?,?,?,?,?,?,?,?,?,?, ?)');
		$result = $this->db->execute($q, $values);
		$this->check_for_error($result);
		
		return $id;
	}
	
	/**
	* Edits resource data in database
	* @param array $rs array of values to edit
	*/
	function edit_resource($rs) {
		$values = array();
		
		$sql = 'SELECT scheduleid FROM ' . $this->get_table('resources') . ' WHERE machid=?';
		$old_id = $this->db->getOne($sql, array($rs['machid']));
		$this->check_for_error($old_id);
		
		array_push($values, $rs['scheduleid']);
		array_push($values, $rs['name']);
		array_push($values, $rs['location']);
		array_push($values, $rs['rphone']);
		array_push($values, $rs['notes']);
		array_push($values, $rs['minRes']);
		array_push($values, $rs['maxRes']);
		array_push($values, intval(isset($rs['autoAssign'])));
		array_push($values, intval(isset($rs['approval'])));
		array_push($values, intval(isset($rs['allow_multi'])));
		array_push($values, $rs['machid']);
		
		$sql = 'UPDATE '. $this->get_table('resources') . ' SET '
				. 'scheduleid=?, name=?, location=?, rphone=?, notes=?, minRes=?, maxRes=?, autoAssign=?, approval=?, allow_multi=? WHERE machid=?';
		
		$q = $this->db->prepare($sql);
		$result = $this->db->execute($q, $values);
		
		if ($old_id != $rs['scheduleid']) {		// Update reservations if schedule changes
			$sql = 'UPDATE ' . $this->get_table('reservations') . ' SET scheduleid=? WHERE machid=?';
			$result = $this->db->query($sql, array($rs['scheduleid'], $rs['machid']));
			$this->check_for_error($result);
		}
	}
	
	/**
	* Deletes a list of resources from the database
	* @param array $rs list of machids to delete
	*/
	function del_resource($rs) { 
		$rs_list = $this->make_del_list($rs); 
	 
		// Get all the ids of reservations that are associated with these schedules 
		$result = $this->db->query('SELECT resid FROM ' . $this->get_table('reservations') . ' WHERE machid IN (' . $rs_list . ')'); 
		$this->check_for_error($result); 
		$results = array(); 
		while ($rs = $result->fetchRow()) { 
			$results[] = $rs['resid']; 
		} 
		 
		$resids = $this->make_del_list($results); 
		$result->free(); 
		 
		// Delete out of the reservation_users table 
		$result = $this->db->query('DELETE FROM ' . $this->get_table('reservation_users') . ' WHERE resid IN (' . $resids . ')'); 
		$this->check_for_error($result); 
		 
		// Delete out of the reservations table 
		$result = $result = $this->db->query('DELETE FROM ' . $this->get_table('reservations') . ' WHERE machid IN (' . $rs_list . ')'); 
		$this->check_for_error($result); 
		 
		// Delete resources 
		$result = $this->db->query('DELETE FROM ' . $this->get_table('resources') . ' WHERE machid IN (' . $rs_list . ')'); 
		$this->check_for_error($result); 
		 
		// Delete all reservations and the associated record in reservation_users using these resources 
		//$result = $this->db->query('DELETE r, ru FROM ' . $this->get_table('reservations') . ' r LEFT JOIN ' . $this->get_table('reservation_users') . ' ru ON r.resid = ru.resid WHERE r.machid IN (' . $rs_list . ')'); 
		//$this->check_for_error($result); 
		 
		// Delete permissions 
		$result = $this->db->query('DELETE FROM ' . $this->get_table('permission') . ' WHERE machid IN (' . $rs_list . ')'); 
		$this->check_for_error($result);
	}
	
	/**
	* Toggles a resource active/inactive
	* @param string $machid id of resource to toggle
	* @param string $status current status of the resource
	*/
	function tog_resource($machid, $status) {
		$status = ($status == 'a') ? 'u' : 'a';
		$result = $this->db->query('UPDATE ' . $this->get_table('resources') . ' SET status=? WHERE machid=?', array($status, $machid));
		$this->check_for_error($result);
	}
	
	/**
	* Clears all user permissions
	* @param string $memberid member id to clear
	*/
	function clear_perms($memberid) {
		$result = $this->db->query('DELETE FROM ' . $this->get_table('permission') . ' WHERE memberid=?', array($memberid));	
		$this->check_for_error($result);
	}
	
	/**
	* Sets user permissions for resources
	* @param string $memberid member's id
	* @param array $machids array of machids to set
	*/
	function set_perms($memberid, $machids) {
		// Create values array for prepared query
		$values = array();
		for ($i = 0; $i < count($machids); $i++) {
			$values[$i] = array($memberid, $machids[$i]);
		}
		
		$query = 'INSERT INTO ' . $this->get_table('permission') . ' VALUES (?,?)';
		// Prepare query
		$q = $this->db->prepare($query);
		// Execute query
		$result = $this->db->executeMultiple($q, $values);
		$this->check_for_error($result);
		
		unset($values);
	}
	
		/**
	* Returns an array of data about a announcement
	* @param int $announcementid announcement id
	* @return array of data associated with that announcement
	*/
	function get_announcement_data($announcementid) {
		
		$result = $this->db->getRow('SELECT * FROM ' . $this->get_table('announcements') . ' WHERE announcementid=?', array($announcementid));
		// Check query
		$this->check_for_error($result);
		
		if (count($result) <= 0) {
			$this->err_msg = 'No results';
			return false;
		}
		
		return $this->cleanRow($result);
	}
	
	/**
	* Inserts a new announcement into the database
	* @param array $rs array of announcement data
	*/
	function add_announcement($rs) {		
		$id = $this->get_new_id();
		
		$values = array($id, $rs['announcement'], $rs['number'], $rs['start_datetime'], $rs['end_datetime']);				
		
		$q = $this->db->prepare('INSERT INTO ' . $this->get_table('announcements')
			. ' VALUES(?,?,?,?,?)');
			
		$result = $this->db->execute($q, $values);
		$this->check_for_error($result);
		
		return $id;
	}
	
	/**
	* Edits announcement data in database
	* @param array $rs array of values to edit
	*/
	function edit_announcement($rs) {
		$values = array($rs['announcement'], $rs['number'], $rs['start_datetime'], $rs['end_datetime'], $rs['announcementid']);
				
		$sql = 'UPDATE '. $this->get_table('announcements') . ' SET'
				. ' announcement=?, number=?, start_datetime=?, end_datetime=?'
				. ' WHERE announcementid=?';
				
		$q = $this->db->prepare($sql);
		$result = $this->db->execute($q, $values);
		$this->check_for_error($result);
	}
	
    /**
	* Deletes announcement data from database
	* @param array $rs array of values to edit
	*/
	function del_announcement($announcements) {
		
		$announcementids = $this->make_del_list($announcements);

		// Delete all reservations for these schedules
		$result = $this->db->query('DELETE FROM ' . $this->get_table('announcements') . ' WHERE announcementid IN(' . $announcementids . ')');
		$this->check_for_error($result);		
	}
	
	/**
	* Get a list of users, emails
	* @param none
	* @return array of email data
	*/
	function get_user_email() {
		global $conf;
		$return = array();
		
		// Select all users in the system
		$result = $this->db->query('SELECT fname, lname, email FROM ' . $this->get_table('login') . ' WHERE email <> ? ORDER BY lname, fname', array($conf['app']['adminEmail']));
		// Check query
		$this->check_for_error($result);
		
		if ($result->numRows() <= 0) {
			$this->err_msg = translate('No results');
			return false;
		}
				
		while ($rs = $result->fetchRow()) {
			$return[] = $this->cleanRow($rs);
		}
		
		$result->free();
		
		return $return;
	}
	
	/**
	* Automatically give permission to all users in the system to use this resource
	* @param string $machid id of resource to auto-assign
	*/
	function auto_assign($machid) {
		$values = array();
		$users = array();
		
		$result = $this->db->getOne('SELECT COUNT(machid) AS num FROM ' . $this->get_table('permission') . ' WHERE machid = ?', array($machid)); 
		$this->check_for_error($result);		// Check if this resource is in the permission table
		
		if ($result['num'] > 0) {				// If it is, only get the users who do not already have permission			
			$exclude_members = array();
			$result = $this->db->query('SELECT memberid FROM ' . $this->get_table('permission') . ' WHERE machid=?', array($machid));
			$this->check_for_error($result);
			
			while($rs = $result->fetchRow())
				$exclude_members[] = $this->db->quote($rs['memberid']);
			
			$result = $this->db->query('SELECT memberid FROM ' . $this->get_table('login') . ' WHERE memberid NOT IN (' . join(',', $exclude_members) . ')');
			$this->check_for_error($result);
			while ($rs = $result->fetchRow())
				$users[]['memberid'] = $rs['memberid'];
		}
		else {									// Else get all users
			$users = $this->get_table_data('login', array('memberid'));
		}

		for ($i = 0; $i<count($users); $i++) {
			array_push($values, array($users[$i]['memberid'], $machid));
		}
		
		if (count($values) > 0 ) {
			$q = $this->db->prepare('INSERT INTO ' . $this->get_table('permission') . ' VALUES (?,?)');
			$result = $this->db->executeMultiple($q, $values);
			
			$this->check_for_error($result);
		}
	}
	
	/**
	* Reset a password for a user
	* @param string $memberid id of user to reset password for
	* @param string $new_password new password value for the user
	*/
	function reset_password($memberid, $new_password) {
		$result = $this->db->query('UPDATE ' . $this->get_table('login') . ' SET password=? WHERE memberid=?', array($this->make_password($new_password), $memberid));
		$this->check_for_error($result);
	}
	
	/**
	* Change the is_admin status for this user to the new status value
	* @param string $memberid ID of the member to update
	* @param int $new_status new is_admin status value
	*/
	function change_admin_status($memberid, $new_status) {
		$result = $this->db->query('UPDATE ' . $this->get_table('login') . ' SET is_admin = ? WHERE memberid=?', array($new_status, $memberid));
		$this->check_for_error($result);
	}
}
?>
